==> hk2-config-2.1.28-sources.jar: org/jvnet/hk2/config/ConfigPopulatorException.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2007-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.jvnet.hk2.config;

import org.jvnet.hk2.component.ComponentException;

import javax.xml.stream.Location;

/**
 * Indicates a problem during population on config beans.
 *
 * @author Kohsuke Kawaguchi
 */
public class ConfigPopulatorException extends ComponentException {
    private Location location;

    public ConfigPopulatorException(String message) {
        super(message);
    }

    public ConfigPopulatorException(String message, Throwable origin) {
        super(message, origin);
    }

    /**
     * Sets the location.
     *
     * This value is not set in the constructor so that we don't need to
     * carry around {@link org.jvnet.hk2.config.Dom} to everywhere.
     */
    void setLocation(Location location) {
        assert this.location==null;
        this.location = location;
    }

    /**
     * Indicates the source position of the configuration file
     * where the problem happened.
     */
    public Location getLocation() {
        return location;
    }

    public String getMessage() {
        if(location==null)
            return super.getMessage();
        return String.format("%s at %s line %d",
            super.getMessage(), location.getSystemId(), location.getLineNumber());
    }
}

==> hk2-config-2.1.92-sources.jar: org/jvnet/hk2/config/ConfigPopulatorException.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2007-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.jvnet.hk2.config;

import javax.xml.stream.Location;

import org.glassfish.hk2.api.HK2RuntimeException;

/**
 * Indicates a problem during population on config beans.
 *
 * @author Kohsuke Kawaguchi
 */
public class ConfigPopulatorException extends HK2RuntimeException {
    private Location location;

    public ConfigPopulatorException(String message) {
        super(message);
    }

    public ConfigPopulatorException(String message, Throwable origin) {
        super(message, origin);
    }

    /**
     * Sets the location.
     *
     * This value is not set in the constructor so that we don't need to
     * carry around {@link org.jvnet.hk2.config.Dom} to everywhere.
     */
    void setLocation(Location location) {
        assert this.location==null;
        this.location = location;
    }

    /**
     * Indicates the source position of the configuration file
     * where the problem happened.
     */
    public Location getLocation() {
        return location;
    }

    public String getMessage() {
        if(location==null)
            return super.getMessage();
        return String.format("%s at %s line %d",
            super.getMessage(), location.getSystemId(), location.getLineNumber());
    }
}
